## Magic Formula

The Magic Formula looks for companies with high Earnings Yield and high Return on Tanglible Capital.

$$
\text{Earnings Yield} = \frac{\text{EBIT}}{\text{Enterprise Value}}   \tag{1}
$$

$$
\text{Enterprise Value} = \text{Market Cap} + \text{Total Debt} - \text{Cash and Cash Equivalents}    \tag{1.1}
$$


$$
\text{Return on Capital (ROC)} = \frac{EBIT}{\text{Tangible Capital}}   \tag{2}
$$


$$
\text{Tangible Capital} = \text{Net Working Capital} + \text{Net Fixed Assets}   \tag{2.1}
$$


$$
\text{Net Working Capital} = \text{Current Assets} - \text{Current Liabilities}   \tag{2.2}
$$

$$
\text{Net Fixed Assets} = \text{PPE} + \text{Right of Use Assets}   \tag{2.3}
$$

